slepc-3.18.0 2022-10-01
Report Typos and Errors

# MFNGetType

Gets the MFN type as a string from the MFN object.

### Synopsis

    #include "slepcmfn.h"
    PetscErrorCode MFNGetType(MFN mfn,MFNType *type)

Not Collective

### Input Parameter

| mfn | - the matrix function context

### Output Parameter

| type | - name of MFN method

### See Also

MFNSetType()

### Level

intermediate

### Location

src/mfn/interface/mfnbasic.c
Index of all MFN routines
Table of Contents for all manual pages
Index of all manual pages